@@ -418,6 +418,7 @@ class Songs(ViewContainer):
         self._iconHeight = 32
         self._iconWidth = 32
         self._add_list_renderers()
+        self.view.get_generic_view().get_style_context().remove_class('content-view')
         self.player = player
         self.player.connect('playlist-item-changed', self.update_model)
 
@@ -488,6 +489,7 @@ class Songs(ViewContainer):
     @log
     def _add_list_renderers(self):
         list_widget = self.view.get_generic_view()
+        list_widget.set_halign(Gtk.Align.CENTER)
         cols = list_widget.get_columns()
         cells = cols[0].get_cells()
         cells[2].set_visible(False)
@@ -507,16 +509,13 @@ class Songs(ViewContainer):
             xalign=0.0,
             yalign=0.5,
             height=48,
+            width=300,
             ellipsize=Pango.EllipsizeMode.END
         )
 
-        col = Gtk.TreeViewColumn()
-        col.set_expand(True)
-        col.pack_start(title_renderer, True)
-        col.set_cell_data_func(title_renderer,
-                               self._on_list_widget_title_render, None)
-        col.add_attribute(title_renderer, 'text', 2)
-        list_widget.insert_column(col, 1)
+        list_widget.add_renderer(title_renderer,
+                                 self._on_list_widget_title_render, None)
+        cols[0].add_attribute(title_renderer, 'text', 2)
 
         self.star_handler._add_star_renderers(list_widget, cols)
 
@@ -534,7 +533,7 @@ class Songs(ViewContainer):
 
         artist_renderer = Gd.StyledTextRenderer(
             xpad=32,
-            width=100,
+            width=300,
             ellipsize=Pango.EllipsizeMode.END
         )
         artist_renderer.add_class('dim-label')
@@ -549,7 +548,7 @@ class Songs(ViewContainer):
 
         type_renderer = Gd.StyledTextRenderer(
             xpad=32,
-            width=100,
+            width=300,
             ellipsize=Pango.EllipsizeMode.END
         )
         type_renderer.add_class('dim-label')
@@ -821,6 +820,7 @@ class Playlist(ViewContainer):
         self.view.get_generic_view().get_style_context()\
             .add_class('songs-list')
         self._add_list_renderers()
+        self.view.get_generic_view().get_style_context().remove_class('content-view')
 
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Music/PlaylistControls.ui')
@@ -1341,8 +1341,6 @@ class Search(ViewContainer):
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'search', None, window, Gd.MainViewType.LIST)
-        self.view.set_halign(Gtk.Align.CENTER)
-        self.view.set_size_request(530, -1)
         self._items = {}
         self.isStarred = None
         self.iter_to_clean = None
@@ -1551,6 +1549,8 @@ class Search(ViewContainer):
     @log
     def _add_list_renderers(self):
         list_widget = self.view.get_generic_view()
+        list_widget.set_halign(Gtk.Align.CENTER)
+        list_widget.set_size_request(530, -1)
         cols = list_widget.get_columns()
 
         title_renderer = Gtk.CellRendererText(
